@@ -236,7 +236,7 @@ void GraphicsCache::eraseLastArmyItem()
 
 
 std::vector<PixMask*>
-disassemble_row(const std::string &file, int no, bool &broken)
+disassemble_row(const Glib::ustring &file, int no, bool &broken)
 {
   Glib::RefPtr<Gdk::Pixbuf> row;
   try
@@ -303,12 +303,12 @@ bool GraphicsCache::loadCursorPics()
   return true;
 }
 
-PixMask* GraphicsCache::getMiscPicture(std::string picname, bool alpha)
+PixMask* GraphicsCache::getMiscPicture(Glib::ustring picname, bool alpha)
 {
   return loadImage(File::getMiscFile("/various/" + picname), alpha);
 }
 
-PixMask* GraphicsCache::loadImage(std::string filename, bool alpha)
+PixMask* GraphicsCache::loadImage(Glib::ustring filename, bool alpha)
 {
   bool broken = false;
   return PixMask::create(filename, broken);
