@@ -1,4 +1,4 @@
-// Copyright (C) 2011 Ben Asselstine
+// Copyright (C) 2011, 2014 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 #include "player.h"
 #include "stacklist.h" //remove me
 
-std::string Action::d_tag = "action";
+Glib::ustring Action::d_tag = "action";
 using namespace std;
 
 #define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<< x << endl<<flush;}
@@ -45,7 +45,7 @@ Action::Action(const Action &action)
 }
 Action::Action(XML_Helper *helper)
 {
-  std::string type_str;
+  Glib::ustring type_str;
   helper->getData(type_str, "type");
   d_type = actionTypeFromString(type_str);
 }
@@ -69,7 +69,7 @@ bool Action::saveContents(XML_Helper* helper) const
 {
     bool retval = true;
 
-    std::string type_str = actionTypeToString(Action::Type(d_type));
+    Glib::ustring type_str = actionTypeToString(Action::Type(d_type));
     retval &= helper->saveData("type", type_str);
     retval &= doSave(helper);
 
@@ -78,7 +78,7 @@ bool Action::saveContents(XML_Helper* helper) const
 
 Action* Action::handle_load(XML_Helper* helper)
 {
-  std::string type_str;
+  Glib::ustring type_str;
 
   helper->getData(type_str, "type");
   Action::Type t = actionTypeFromString(type_str);
@@ -190,7 +190,7 @@ Action_Move::~Action_Move()
 {
 }
 
-std::string Action_Move::dump() const
+Glib::ustring Action_Move::dump() const
 {
     std::stringstream s;
 
@@ -238,7 +238,7 @@ Action_Fight::Action_Fight(const Action_Fight &action)
 Action_Fight::Action_Fight(XML_Helper* helper)
     :Action(helper)
 {
-    std::string s;
+    Glib::ustring s;
     std::istringstream si;
     int ival = -1;
 
@@ -266,7 +266,7 @@ Action_Fight::Action_Fight(XML_Helper* helper)
       }
 }
 
-bool Action_Fight::loadItem(std::string tag, XML_Helper* helper)
+bool Action_Fight::loadItem(Glib::ustring tag, XML_Helper* helper)
 {
     FightItem item;
     
@@ -287,7 +287,7 @@ Action_Fight::~Action_Fight()
 {
 }
 
-std::string Action_Fight::dump() const
+Glib::ustring Action_Fight::dump() const
 {
     std::stringstream s;
     std::list<guint32>::const_iterator uit;
@@ -424,7 +424,7 @@ Action_Resign::~Action_Resign()
 {
 }
 
-std::string Action_Resign::dump() const
+Glib::ustring Action_Resign::dump() const
 {
   std::stringstream s;
   s << "this player resigns\n";
@@ -466,7 +466,7 @@ Action_EndTurn::~Action_EndTurn()
 {
 }
 
-std::string Action_EndTurn::dump() const
+Glib::ustring Action_EndTurn::dump() const
 {
   return "ending turn\n";
 }
@@ -501,7 +501,7 @@ Action_RenamePlayer::~Action_RenamePlayer()
 {
 }
 
-std::string Action_RenamePlayer::dump() const
+Glib::ustring Action_RenamePlayer::dump() const
 {
     std::stringstream s;
 
@@ -519,7 +519,7 @@ bool Action_RenamePlayer::doSave(XML_Helper* helper) const
     return retval;
 }
 
-bool Action_RenamePlayer::fillData(std::string name)
+bool Action_RenamePlayer::fillData(Glib::ustring name)
 {
   d_name = name;
   return true;
@@ -565,7 +565,7 @@ bool Action_InitTurn::fillData(int die1, int die2, int die3, int die4)
   return true;
 }
 
-std::string Action_InitTurn::dump() const
+Glib::ustring Action_InitTurn::dump() const
 {
   std::stringstream ss;
   ss <<"player starts turn with dice:";
@@ -609,7 +609,7 @@ Action_Kill::~Action_Kill()
 {
 }
 
-std::string Action_Kill::dump() const
+Glib::ustring Action_Kill::dump() const
 {
   std::stringstream ss;
   ss <<"player is vanquished.";
@@ -652,7 +652,7 @@ Action_SelectStack::~Action_SelectStack()
 {
 }
 
-std::string Action_SelectStack::dump() const
+Glib::ustring Action_SelectStack::dump() const
 {
   std::stringstream ss;
 
@@ -696,7 +696,7 @@ Action_DeselectStack::~Action_DeselectStack()
 {
 }
 
-std::string Action_DeselectStack::dump() const
+Glib::ustring Action_DeselectStack::dump() const
 {
   std::stringstream ss;
 
@@ -735,7 +735,7 @@ Action_Reinforcements::Action_Reinforcements(XML_Helper* helper)
                         sigc::mem_fun(this, &Action_Reinforcements::loadStack));
 }
 
-bool Action_Reinforcements::loadStack(std::string tag, XML_Helper* helper)
+bool Action_Reinforcements::loadStack(Glib::ustring tag, XML_Helper* helper)
 {
   if (tag == Stack::d_tag)
     {
@@ -749,7 +749,7 @@ Action_Reinforcements::~Action_Reinforcements()
 {
 }
 
-std::string Action_Reinforcements::dump() const
+Glib::ustring Action_Reinforcements::dump() const
 {
     std::stringstream s;
     std::list<guint32>::const_iterator uit;
@@ -800,7 +800,7 @@ Action_DieSelected::~Action_DieSelected()
 {
 }
 
-std::string Action_DieSelected::dump() const
+Glib::ustring Action_DieSelected::dump() const
 {
   std::stringstream ss;
 
@@ -822,7 +822,7 @@ bool Action_DieSelected::fillData(guint idx)
   return true;
 }
 
-std::string Action::actionTypeToString(Action::Type type)
+Glib::ustring Action::actionTypeToString(Action::Type type)
 {
   switch (type)
     {
@@ -853,7 +853,7 @@ std::string Action::actionTypeToString(Action::Type type)
   return "Action::MOVE";
 }
 
-Action::Type Action::actionTypeFromString(std::string str)
+Action::Type Action::actionTypeFromString(Glib::ustring str)
 {
   if (str.size() > 0 && isdigit(str.c_str()[0]))
     return Action::Type(atoi(str.c_str()));
