@@ -255,7 +255,7 @@ void Game::stopGame()
   d_nextTurn->stop();
 }
 
-bool Game::saveGame(std::string file)
+bool Game::saveGame(Glib::ustring file)
 {
   return d_gameScenario->saveGame(file);
 }
