@@ -720,7 +720,7 @@ void GameWindow::on_load_game_activated()
 
   if (res == Gtk::RESPONSE_ACCEPT)
     {
-      std::string filename = chooser.get_filename();
+      Glib::ustring filename = chooser.get_filename();
       current_save_filename = filename;
       d_load_filename = filename;
       stop_game("load-game");
@@ -762,7 +762,7 @@ void GameWindow::on_save_game_as_activated()
 
   if (res == Gtk::RESPONSE_ACCEPT)
     {
-      std::string filename = chooser.get_filename();
+      Glib::ustring filename = chooser.get_filename();
 
       current_save_filename = filename;
 
@@ -906,7 +906,7 @@ void GameWindow::on_help_about_activated()
   return;
 }
 
-void GameWindow::stop_game(std::string action)
+void GameWindow::stop_game(Glib::ustring action)
 {
   stop_action = action;
   if (game)
@@ -970,7 +970,7 @@ void GameWindow::on_player_died(Player *player)
   dialog.hide();
 }
 
-void GameWindow::on_message_requested(std::string msg)
+void GameWindow::on_message_requested(Glib::ustring msg)
 {
   Gtk::MessageDialog dialog(*window, msg);
   dialog.show_all();
