@@ -90,7 +90,7 @@ class GameWindow
     DiceBox *p2_dicebox;
     Gtk::Statusbar *statusbar;
 
-    std::string current_save_filename;
+    Glib::ustring current_save_filename;
 
     Game* game;
     std::list<sigc::connection> connections;
@@ -118,7 +118,7 @@ class GameWindow
     void on_help_about_activated();
     void on_online_help_activated();
 
-    void on_message_requested(std::string msg);
+    void on_message_requested(Glib::ustring msg);
     
     // game callbacks
     void on_next_player_turn(Player *player, unsigned int turn_number);
@@ -143,7 +143,7 @@ class GameWindow
     //helpers
     bool setup_game(GameScenario *game_scenario, NextTurn *nextTurn);
     void setup_signals(GameScenario *game_scenario);
-    void stop_game(std::string action);
+    void stop_game(Glib::ustring action);
     void setup_menuitem(Gtk::MenuItem*, sigc::slot<void> , sigc::signal<void, bool> &);
 
     void give_some_cheese(Player *game_winner);
@@ -154,10 +154,10 @@ class GameWindow
     Raft* raft_is_currently_moving;
 
 public:
-    std::string stop_action; //hackhackhack
-    std::string d_scenario;
-    std::string d_player_name;
-    std::string d_load_filename;
+    Glib::ustring stop_action; //hackhackhack
+    Glib::ustring d_scenario;
+    Glib::ustring d_player_name;
+    Glib::ustring d_load_filename;
 };
 
 #endif
