@@ -1,4 +1,4 @@
-//  Copyright (C) 2011 Ben Asselstine
+//  Copyright (C) 2011, 2014 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@ class Main: public sigc::trackable
     void stop_main_loop();
     bool iterate_main_loop();
 
-    std::string load_filename;
+    Glib::ustring load_filename;
     guint32 random_number_seed;
     
  private:
