@@ -1,4 +1,4 @@
-// Copyright (C) 2011 Ben Asselstine
+// Copyright (C) 2011, 2014 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -40,14 +40,12 @@
 #include "MoveResult.h"
 #include "raft.h"
 
-using namespace std;
-
 //#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<flush<<endl;}
 #define debug(x)
 
-std::string Player::d_tag = "player";
+Glib::ustring Player::d_tag = "player";
 
-Player::Player(string name, guint32 armyset, Gdk::Color color,
+Player::Player(Glib::ustring name, guint32 armyset, Gdk::RGBA color,
 	       Type type, int player_no)
     :d_color(color), d_name(name), d_armyset(armyset),
     d_dead(false), d_immortal(false), d_type(type),
@@ -98,7 +96,7 @@ Player::Player(XML_Helper* helper)
     helper->getData(d_name, "name");
     helper->getData(d_dead, "dead");
     helper->getData(d_immortal, "immortal");
-    std::string type_str;
+    Glib::ustring type_str;
     helper->getData(type_str, "type");
     d_type = playerTypeFromString(type_str);
     helper->getData(d_color, "color");
@@ -121,7 +119,7 @@ Player::~Player()
     clearHistorylist();
 }
 
-Player* Player::create(std::string name, guint32 armyset, Gdk::Color color, Type type)
+Player* Player::create(Glib::ustring name, guint32 armyset, Gdk::RGBA color, Type type)
 {
   switch(type)
   {
@@ -178,12 +176,12 @@ std::vector<guint32> Player::getDice() const
   return dice;
 }
 
-void Player::setColor(Gdk::Color c)
+void Player::setColor(Gdk::RGBA c)
 {
     d_color = c;
 }
 
-std::string Player::getName() const
+Glib::ustring Player::getName() const
 {
   return d_name;
 }
@@ -274,7 +272,7 @@ bool Player::save(XML_Helper* helper) const
     retval &= helper->saveData("armyset", d_armyset);
     retval &= helper->saveData("dead", d_dead);
     retval &= helper->saveData("immortal", d_immortal);
-    std::string type_str = playerTypeToString(Player::Type(d_type));
+    Glib::ustring type_str = playerTypeToString(Player::Type(d_type));
     retval &= helper->saveData("type", type_str);
     debug("type of " << d_name << " is " << d_type)
 
@@ -296,7 +294,7 @@ bool Player::save(XML_Helper* helper) const
 Player* Player::loadPlayer(XML_Helper* helper)
 {
     Type type;
-    std::string type_str;
+    Glib::ustring type_str;
     helper->getData(type_str, "type");
     type = playerTypeFromString(type_str);
 
@@ -311,7 +309,7 @@ Player* Player::loadPlayer(XML_Helper* helper)
     return 0;
 }
 
-bool Player::load(string tag, XML_Helper* helper)
+bool Player::load(Glib::ustring tag, XML_Helper* helper)
 {
     if (tag == Action::d_tag)
     {
@@ -538,12 +536,12 @@ void Player::resign()
   addAction(item);
 }
 
-void Player::doRename(std::string name)
+void Player::doRename(Glib::ustring name)
 {
   setName(name);
 }
 
-void Player::rename(std::string name)
+void Player::rename(Glib::ustring name)
 {
   doRename(name);
   Action_RenamePlayer * item = new Action_RenamePlayer();
@@ -552,7 +550,7 @@ void Player::rename(std::string name)
   return;
 }
 
-std::string Player::playerTypeToString(const Player::Type type)
+Glib::ustring Player::playerTypeToString(const Player::Type type)
 {
   switch (type)
     {
@@ -564,7 +562,7 @@ std::string Player::playerTypeToString(const Player::Type type)
   return "Player::HUMAN";
 }
 
-Player::Type Player::playerTypeFromString(const std::string str)
+Player::Type Player::playerTypeFromString(const Glib::ustring str)
 {
   if (str.size() > 0 && isdigit(str.c_str()[0]))
     return Player::Type(atoi(str.c_str()));
