@@ -40,7 +40,7 @@ bool Soundset::save(XML_Helper* helper) const
     retval &= helper->begin (ARMY_MUSIC_VERSION);
     retval &= helper->openTag("music");
 
-    for (std::map<std::string,MusicItem*>::const_iterator it = d_musicMap.begin(); it != d_musicMap.end(); it++)
+    for (std::map<Glib::ustring,MusicItem*>::const_iterator it = d_musicMap.begin(); it != d_musicMap.end(); it++)
       {
         retval &= helper->openTag("piece");
         retval &= helper->saveData("name", (*it).first);
@@ -59,7 +59,7 @@ Soundset::Soundset(XML_Helper *helper)
   helper->registerTag("piece", sigc::mem_fun((*this), &Soundset::loadMusic));
 }
 
-bool Soundset::loadMusic(std::string tag, XML_Helper* helper)
+bool Soundset::loadMusic(Glib::ustring tag, XML_Helper* helper)
 {
   if (tag != "piece")
     {
@@ -67,7 +67,7 @@ bool Soundset::loadMusic(std::string tag, XML_Helper* helper)
       return false;
     }
 
-  std::string tagname;
+  Glib::ustring tagname;
   MusicItem* item = new MusicItem();
 
   bool retval = true;
@@ -81,21 +81,21 @@ bool Soundset::loadMusic(std::string tag, XML_Helper* helper)
   return retval;
 }
         
-void Soundset::setPieces(std::map<std::string, MusicItem*> map)
+void Soundset::setPieces(std::map<Glib::ustring, MusicItem*> map)
 {
   d_musicMap = map;
 }
 
-void Soundset::getFilenames(std::list<std::string> &files) const
+void Soundset::getFilenames(std::list<Glib::ustring> &files) const
 {
-  for (std::map<std::string,MusicItem*>::const_iterator i = d_musicMap.begin(); 
+  for (std::map<Glib::ustring,MusicItem*>::const_iterator i = d_musicMap.begin(); 
        i != d_musicMap.end(); i++)
     files.push_back((*i).second->file);
 }
         
-std::string Soundset::getPieceFilename(std::string piecename) const
+Glib::ustring Soundset::getPieceFilename(Glib::ustring piecename) const
 {
-  for (std::map<std::string,MusicItem*>::const_iterator i = d_musicMap.begin(); 
+  for (std::map<Glib::ustring,MusicItem*>::const_iterator i = d_musicMap.begin(); 
        i != d_musicMap.end(); i++)
     {
       if ((*i).first == piecename)
