@@ -28,11 +28,11 @@
 struct MusicItem
 {
     // The file where the sound piece can be loaded from
-    std::string file;
+    Glib::ustring file;
     // Can it be played in the background?
     bool background;
     // If loading this file fails, we can define an alias to load instead.
-    std::string alias;
+    Glib::ustring alias;
 };
 
 
@@ -43,22 +43,22 @@ class Soundset : public sigc::trackable
         Soundset();
         ~Soundset();
 
-        std::map<std::string, MusicItem*> getPieces() const {return d_musicMap;}
-        std::string getPieceFilename(std::string piecename) const;
-        void setPieces(std::map<std::string, MusicItem*> map);
+        std::map<Glib::ustring, MusicItem*> getPieces() const {return d_musicMap;}
+        Glib::ustring getPieceFilename(Glib::ustring piecename) const;
+        void setPieces(std::map<Glib::ustring, MusicItem*> map);
 
         bool save(XML_Helper* helper) const;
 
-        void getFilenames(std::list<std::string> &files) const;
+        void getFilenames(std::list<Glib::ustring> &files) const;
     private:
 
         //! Callback for the music data, see XML_Helper 
-        bool loadMusic(std::string tag, XML_Helper* helper);
+        bool loadMusic(Glib::ustring tag, XML_Helper* helper);
 
 	// DATA
         
         // music is stored here, access by d_musicMap[name]
-        std::map<std::string, MusicItem*> d_musicMap;
+        std::map<Glib::ustring, MusicItem*> d_musicMap;
 };
 
 #endif //SOUNDSET_H
