@@ -29,8 +29,7 @@
 #include "xmlhelper.h"
 #include "player.h"
 
-std::string Stack::d_tag = "stack";
-using namespace std;
+Glib::ustring Stack::d_tag = "stack";
 
 //#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
 #define debug(x)
@@ -108,7 +107,7 @@ bool Stack::save(XML_Helper* helper) const
   return retval;
 }
 
-bool Stack::load(std::string tag, XML_Helper* helper)
+bool Stack::load(Glib::ustring tag, XML_Helper* helper)
 {
 
   if (tag == Army::d_tag)
