@@ -1,7 +1,7 @@
 // Copyright (C) 2002, 2003 Michael Bartl
 // Copyright (C) 2002, 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2003, 2004, 2005 Andrea Paternesi
-// Copyright (C) 2011 Ben Asselstine
+// Copyright (C) 2011, 2012, 2014 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -18,35 +18,29 @@
 //  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
 //  02110-1301, USA.
 
+#include <config.h>
 #include <iostream>
 #include <sstream>
-#include <algorithm>
-#include <stdlib.h>
-#include <string.h>
-#include <zlib.h>
 #include "xmlhelper.h"
 #include "defs.h"
 #include "File.h"
+#include "ucompose.hpp"
 
 //#define debug(x) {std::cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<std::endl<<std::flush;}
 #define debug(x)
-
-//they are only needed later for the expat callbacks
-std::string my_cdata;
-bool error = false;
-    
-std::string XML_Helper::xml_entity = "<?xml version=\"1.0\"?>";
+Glib::ustring XML_Helper::xml_entity = "<?xml version=\"1.0\" encoding=\"utf-8\"?>";
 
 // forward declarations of the internally used functions
-void start_handler(void* udata, const XML_Char* name, const XML_Char** atts);
-void character_handler(void* udata, const XML_Char* s, int len);
-void end_handler(void* udata, const XML_Char* name);
+//void start_handler(void* udata, const XML_Char* name, const XML_Char** atts);
+//void character_handler(void* udata, const XML_Char* s, int len);
+//void end_handler(void* udata, const XML_Char* name);
 
-XML_Helper::XML_Helper(std::string filename, std::ios::openmode mode, bool zip)
-  : d_inbuf(0), d_outbuf(0), d_fout(0), d_fin(0), d_out(0), d_in(0),
-    d_last_opened(""), d_version(""), d_failed(false), d_zip(zip)
+XML_Helper::XML_Helper(Glib::ustring filename, std::ios::openmode mode)
+  : xmlpp::SaxParser(), d_inbuf(0), d_outbuf(0), d_fout(0), d_fin(0), 
+    d_out(0), d_in(0), d_last_opened(""), d_version(""), d_failed(false), 
+    my_cdata(""), error(false)
 {
-    debug("Constructor called  -- " << zip)
+    debug("Constructor called  -- ")
         
     // always use a helper either for reading or for writing. Doing both
     // is propably possible, but there is little point in using it anyway.
@@ -64,57 +58,12 @@ XML_Helper::XML_Helper(std::string filename, std::ios::openmode mode, bool zip)
         if (!(*d_fin))
         //error opening
         {
-            std::cerr <<filename << ": Error opening file for reading. Exiting\n";
+            std::cerr << String::ucompose("Error opening `%1' for reading.  Exiting.", filename) << std::endl;
             exit(-1);
         }
 
-        char tmp;
-        d_fin->read(&tmp,1);
-        debug("IS ZIPPED ->" << tmp)                
-
-        if (d_fin->eof())
-        {
-            std::cerr << "File too short (<=1 byte), propably broken. Skipping load\n";
-            d_failed = true;
-        }
-
-        if (tmp=='Z') 
-        {  
-            std::cout <<filename << ": The file is obfuscated, attempting to read it....\n"; 
-            d_fin->seekg (0,std::ios::end);
-            long length = d_fin->tellg();
-            d_fin->seekg (1, std::ios::beg);    
-
-            uLongf destlen1=0;
-            (*d_fin) >> destlen1;
-
-            debug(destlen1 << " -- "<< length);
-
-            length--;
-            length-=sizeof(uLongf);
-
-            char * buffer = (char*) malloc(length);        
-            char * buf1 = (char *) malloc(destlen1);
-
-            d_fin->read(buffer,length);
-            d_fin->close();
-
-            uncompress((Bytef*)buf1,&destlen1,(Bytef*)buffer,length);
-
-            free(buffer);
-            debug(destlen1 << " -- "<< length);
-        
-            d_inbuf = new std::istringstream(buf1);
-
-            free(buf1);
-            d_in=d_inbuf;
-        }
-        else 
-        {
-            //std::cout <<filename <<_(": The file is not obfuscated, attempting to read it....\n"); 
-            d_fin->seekg(0, std::ios::beg);
-            d_in = d_fin;
-        }
+        d_fin->seekg(0, std::ios::beg);
+        d_in = d_fin;
     }
 
     if (mode & std::ios::out)
@@ -123,7 +72,7 @@ XML_Helper::XML_Helper(std::string filename, std::ios::openmode mode, bool zip)
                                    std::ios::out & std::ios::trunc);
         if (!(*d_fout))
         {
-            std::cerr <<filename << ": Error opening file for writing. Exiting\n";
+            std::cerr << String::ucompose("Error opening `%1' for writing.  Exiting.", filename) << std::endl;
             exit(-1);
         }
 
@@ -134,14 +83,16 @@ XML_Helper::XML_Helper(std::string filename, std::ios::openmode mode, bool zip)
 
 XML_Helper::XML_Helper(std::ostream* output)
   : d_inbuf(0), d_outbuf(0), d_fout(0), d_fin(0), d_out(0), d_in(0),
-    d_last_opened(""), d_version(""), d_failed(false), d_zip(false)
+    d_last_opened(""), d_version(""), d_failed(false), my_cdata(""), 
+    error(false)
 {
   d_out = output;
 }
 
 XML_Helper::XML_Helper(std::istream* input)
   : d_inbuf(0), d_outbuf(0), d_fout(0), d_fin(0), d_out(0), d_in(0),
-    d_last_opened(""), d_version(""), d_failed(false), d_zip(false)
+    d_last_opened(""), d_version(""), d_failed(false), my_cdata(""), 
+    error(false)
 {
   d_in = input;
 }
@@ -149,14 +100,19 @@ XML_Helper::XML_Helper(std::istream* input)
 XML_Helper::~XML_Helper()
 {
     if (d_tags.size() != 0)
+      {
     // should never happen unless there was an error
-        std::cerr << "XML_Helper: dtags not empty!!\n";
+        std::cerr << "Error parsing: ";
+        for (std::list<Glib::ustring>::reverse_iterator i = d_tags.rbegin(); i != d_tags.rend(); i++)
+          std::cerr << (*i) << "/";
+        std::cerr << "\n";
+      }
     
     debug("Called destructor\n")    
     close();
 }
 
-bool XML_Helper::begin(std::string version)
+bool XML_Helper::begin(Glib::ustring version)
 {
     d_version = version;
     (*d_out) << xml_entity << std::endl;
@@ -164,7 +120,7 @@ bool XML_Helper::begin(std::string version)
     return true;
 }
 
-bool XML_Helper::openTag(std::string name)
+bool XML_Helper::openTag(Glib::ustring name)
 {
     if (!d_out)
     {
@@ -198,7 +154,7 @@ bool XML_Helper::closeTag()
         return false;
     }
 
-    std::string name = (*d_tags.begin());
+    Glib::ustring name = (*d_tags.begin());
     
     //remove tag from list
     d_tags.pop_front();
@@ -209,7 +165,7 @@ bool XML_Helper::closeTag()
     return true;
 }
 
-bool XML_Helper::saveData(std::string name, const Gdk::Color value)
+bool XML_Helper::saveData(Glib::ustring name, const Gdk::RGBA value)
 {
     //prepend a "d_" to show that this is a data tag
     name = "d_" + name;
@@ -228,21 +184,21 @@ bool XML_Helper::saveData(std::string name, const Gdk::Color value)
     addTabs();
     char buf[3];
     guint32 r, g, b;
-    r = value.get_red_p() * 255;
-    g = value.get_green_p() * 255;
-    b = value.get_blue_p() * 255;
+    r = value.get_red() * 255;
+    g = value.get_green() * 255;
+    b = value.get_blue() * 255;
     snprintf(buf, sizeof(buf), "%02X", r);
-    std::string red = buf;
+    Glib::ustring red = buf;
     snprintf(buf, sizeof(buf), "%02X", g);
-    std::string green = buf;
+    Glib::ustring green = buf;
     snprintf(buf, sizeof(buf), "%02X", b);
-    std::string blue = buf;
+    Glib::ustring blue = buf;
 
     (*d_out) <<"<" <<name <<">#" <<red <<green<<blue <<"</" <<name <<">\n";
   return true;
 }
 
-bool XML_Helper::saveData(std::string name, std::string value)
+bool XML_Helper::saveData(Glib::ustring name, Glib::ustring value)
 {
     //prepend a "d_" to show that this is a data tag
     name = "d_" + name;
@@ -263,7 +219,7 @@ bool XML_Helper::saveData(std::string name, std::string value)
     return true;
 }
 
-bool XML_Helper::saveData(std::string name, int value)
+bool XML_Helper::saveData(Glib::ustring name, int value)
 {
     //prepend a "d_" to show that this is a data tag
     name = "d_" + name;
@@ -284,7 +240,7 @@ bool XML_Helper::saveData(std::string name, int value)
     return true;
 }
 
-bool XML_Helper::saveData(std::string name, guint32 value)
+bool XML_Helper::saveData(Glib::ustring name, guint32 value)
 {
     //prepend a "d_" to show that this is a data tag
     name = "d_" + name;
@@ -305,7 +261,7 @@ bool XML_Helper::saveData(std::string name, guint32 value)
     return true;
 }
 
-bool XML_Helper::saveData(std::string name, bool value)
+bool XML_Helper::saveData(Glib::ustring name, bool value)
 {
     //prepend a "d_" to show that this is a data tag
     name = "d_" + name;
@@ -321,7 +277,7 @@ bool XML_Helper::saveData(std::string name, bool value)
         return false;
     }
 
-    std::string s;
+    Glib::ustring s;
     s = (value? "true" : "false");
 
     addTabs();
@@ -329,7 +285,7 @@ bool XML_Helper::saveData(std::string name, bool value)
     return true;
 }
 
-bool XML_Helper::saveData(std::string name, double value)
+bool XML_Helper::saveData(Glib::ustring name, double value)
 {
     //prepend a "d_" to show that this is a data tag
     name = "d_" + name;
@@ -350,59 +306,23 @@ bool XML_Helper::saveData(std::string name, double value)
     return true;
 }
 
-/* This is a wrapper for the AMD64 platform */
-bool XML_Helper::saveData(std::string name, unsigned long int value)
+bool XML_Helper::saveData(Glib::ustring name, unsigned long int value)
 {
     return saveData(name, static_cast<guint32>(value));
 }
-/* End wrapper AMD64 */
 
 bool XML_Helper::close()
 {
     if (d_outbuf)        
-    {
-        if (d_zip)        
-        {
-            debug("I zip IT")
-            debug("Saving game and obfuscating the Savefile.\n") 
-            std::string tmp = d_outbuf->str();
-            tmp+='\0';
+      {
+        std::string tmp = d_outbuf->str();
+        d_fout->write(tmp.c_str(), tmp.length());
+        d_fout->flush();
 
-            long origlength = tmp.length();
-            uLongf ziplength = static_cast<uLongf>(origlength + (12+0.01*origlength));
-            char *buf1= (char*) malloc(ziplength);
-         
-            int ret = compress2((Bytef*)buf1, &ziplength,
-                                (Bytef*)tmp.c_str(), (uLong)origlength, 9);
-            debug("RET="<<ret<<" length=" << origlength << " destlen1=" << ziplength)
-
-            (*d_fout) << 'Z';
-            (*d_fout) << origlength;
-
-            d_fout->write(buf1, ziplength);
-            d_fout->flush();
-
-            free(buf1);
-            delete d_outbuf;
-
-            d_outbuf = 0;
-            debug("destroyed d_outbuf")
-            ret=0;// to avoid warning 
-        }
-        else 
-        {
-            debug("I do not zip IT")
-            debug(_("Saving game without obfuscation.\n")) 
-
-            std::string tmp = d_outbuf->str();
-            d_fout->write(tmp.c_str(), tmp.length());
-            d_fout->flush();
-
-            delete d_outbuf;
-            d_outbuf = 0;
-            debug("destroyed d_outbuf")
-        }
-    }
+        delete d_outbuf;
+        d_outbuf = 0;
+        debug("destroyed d_outbuf")
+      }
 
     if (d_inbuf)        
     {
@@ -438,7 +358,7 @@ void XML_Helper::addTabs()
 }
 
 //loading
-bool XML_Helper::registerTag(std::string tag, XML_Slot callback)
+bool XML_Helper::registerTag(Glib::ustring tag, XML_Slot callback)
 {
     //register tag as important
     d_callbacks[tag] = callback;
@@ -446,9 +366,9 @@ bool XML_Helper::registerTag(std::string tag, XML_Slot callback)
     return true;
 }
 
-bool XML_Helper::unregisterTag(std::string tag)
+bool XML_Helper::unregisterTag(Glib::ustring tag)
 {
-    std::map<std::string, XML_Slot>::iterator it = d_callbacks.find(tag);
+    std::map<Glib::ustring, XML_Slot>::iterator it = d_callbacks.find(tag);
 
     if (it == d_callbacks.end())
     //item doesn't exist
@@ -458,24 +378,24 @@ bool XML_Helper::unregisterTag(std::string tag)
     return true;
 }
 
-bool XML_Helper::getData(Gdk::Color& data, std::string name)
+bool XML_Helper::getData(Gdk::RGBA & data, Glib::ustring name)
 {
     //the data tags are stored with leading "d_", so prepend it here
     name = "d_" + name;
 
-    std::map<std::string, std::string>::const_iterator it;
+    std::map<Glib::ustring, Glib::ustring>::const_iterator it;
 
     it = d_data.find(name);
     
     if (it == d_data.end())
     {
-        data.set_rgb_p(0,0,0);
-        std::cerr<<"XML_Helper::getData(Gdk::Color, \"" <<name <<"\") failed\n";
+        data.set_rgba(0,0,0);
+        std::cerr<<String::ucompose("Error!  couldn't get Gdk::RGBA value from xml tag `%1'.", name) << std::endl;
         d_failed = true;
         return false;
     }
     
-    std::string value = (*it).second;
+    Glib::ustring value = (*it).second;
     char buf[15];
     int retval = sscanf(value.c_str(), "%s", buf);
     if (retval == -1)
@@ -500,24 +420,24 @@ bool XML_Helper::getData(Gdk::Color& data, std::string name)
 	    blue > 255 || blue < 0)
 	  return false;
       }
-    data.set_rgb_p((float)red / 255.0, (float)green / 255.0,
+    data.set_rgba((float)red / 255.0, (float)green / 255.0,
 		   (float)blue / 255.0);
   return true;
 }
 
-bool XML_Helper::getData(std::string& data, std::string name)
+bool XML_Helper::getData(Glib::ustring& data, Glib::ustring name)
 {
     //the data tags are stored with leading "d_", so prepend it here
     name = "d_" + name;
 
-    std::map<std::string, std::string>::const_iterator it;
+    std::map<Glib::ustring, Glib::ustring>::const_iterator it;
 
     it = d_data.find(name);
     
     if (it == d_data.end())
     {
         data = "";
-        std::cerr<<"XML_Helper::getData(std::string, \"" <<name <<"\") failed\n";
+        std::cerr<<String::ucompose("Error!  couldn't get Glib::ustring value from xml tag `%1'.", name) << std::endl;
         d_failed = true;
         return false;
     }
@@ -527,17 +447,17 @@ bool XML_Helper::getData(std::string& data, std::string name)
     return true;
 }
 
-bool XML_Helper::getData(bool& data, std::string name)
+bool XML_Helper::getData(bool& data, Glib::ustring name)
 {
     //the data tags are stored with leading "d_", so prepend it here
     name = "d_" + name;
 
-    std::map<std::string, std::string>::const_iterator it;
+    std::map<Glib::ustring, Glib::ustring>::const_iterator it;
     it = d_data.find(name);
 
     if (it == d_data.end())
     {
-        std::cerr<<"XML_Helper::getData(bool, \"" <<name <<"\") failed\n";
+        std::cerr<<String::ucompose("Error!  couldn't get bool value from xml tag `%1'.", name) << std::endl;
         d_failed = true;
         return false;
     }
@@ -557,17 +477,17 @@ bool XML_Helper::getData(bool& data, std::string name)
     return false;
 }
 
-bool XML_Helper::getData(int& data, std::string name)
+bool XML_Helper::getData(int& data, Glib::ustring name)
 {
     //the data tags are stored with leading "d_", so prepend it here
     name = "d_" + name;
 
-    std::map<std::string, std::string>::const_iterator it;
+    std::map<Glib::ustring, Glib::ustring>::const_iterator it;
     it = d_data.find(name);
 
     if (it == d_data.end())
     {
-        std::cerr<<"XML_Helper::getData(int, \"" <<name <<"\") failed\n";
+        std::cerr<<String::ucompose("Error!  couldn't get int value from xml tag `%1'.", name) << std::endl;
         d_failed = true;
         return false;
     }
@@ -576,17 +496,17 @@ bool XML_Helper::getData(int& data, std::string name)
     return true;
 }
 
-bool XML_Helper::getData(guint32& data, std::string name)
+bool XML_Helper::getData(guint32& data, Glib::ustring name)
 {
     //the data tags are stored with leading "d_", so prepend it here
     name = "d_" + name;
 
-    std::map<std::string, std::string>::const_iterator it;
+    std::map<Glib::ustring, Glib::ustring>::const_iterator it;
     it = d_data.find(name);
 
     if (it == d_data.end())
     {
-        std::cerr<<"XML_Helper::getData(guint32, \"" <<name <<"\") failed\n";
+        std::cerr<<String::ucompose("Error!  couldn't get guint32 value from xml tag `%1'.", name) << std::endl;
         d_failed = true;
         return false;
     }
@@ -597,17 +517,17 @@ bool XML_Helper::getData(guint32& data, std::string name)
     
 }
 
-bool XML_Helper::getData(double& data, std::string name)
+bool XML_Helper::getData(double& data, Glib::ustring name)
 {
     //the data tags are stored with leading "d_", so prepend it here
     name = "d_" + name;
 
-    std::map<std::string, std::string>::const_iterator it;
+    std::map<Glib::ustring, Glib::ustring>::const_iterator it;
     it = d_data.find(name);
 
     if (it == d_data.end())
     {
-        std::cerr<<"XML_Helper::getData(double, \"" <<name <<"\") failed\n";
+        std::cerr<<String::ucompose("Error!  couldn't get double value from xml tag `%1'.", name) << std::endl;
         d_failed = true;
         return false;
     }
@@ -616,52 +536,39 @@ bool XML_Helper::getData(double& data, std::string name)
     return true;
 }
 
-bool XML_Helper::parse()
+bool XML_Helper::parseXML()
 {
-    if (!d_in || d_failed)
-        return false;
-        //what's the use of parsing no or incorrect input?
+  if (!d_in || d_failed)
+    return false;
 
-    d_parser = XML_ParserCreate("utf-8");
+  char buffer[1024];
+    do 
+      {
+        memset (buffer, 0, sizeof (buffer));
+        d_in->read(buffer, sizeof (buffer) - 1);
+        Glib::ustring input(buffer);
+        parse_chunk(input);
+        if (d_failed)
+          break;
+      } while (*d_in);
+  
+  if (!d_failed)
+    finish_chunk_parsing();
 
-    //set handlers and data
-    XML_SetElementHandler(d_parser, start_handler, end_handler);
-    XML_SetCharacterDataHandler(d_parser, character_handler);
-    XML_SetUserData(d_parser, static_cast<void*>(this));
-
-    while (!d_in->eof() && !d_failed)
-    {
-        char* buffer = static_cast<char*>(XML_GetBuffer(d_parser,1000));
-        d_in->getline(buffer, 1000);
-        bool my_eof = d_in->eof();
-
-        if (!XML_ParseBuffer(d_parser, strlen(buffer), my_eof))
-        //error parsing
-        {
-            std::cerr <<"XML_Helper: error parsing xml document.\n";
-            std::cerr <<"Line " <<XML_GetCurrentLineNumber(d_parser);
-            std::cerr <<": " <<XML_ErrorString(XML_GetErrorCode(d_parser)) <<"\n";
-            std::cerr <<"Buffercontent = " << buffer << std::endl;
-            d_failed = true;
-        }
-    }
-
-    XML_ParserFree(d_parser);
-
-    return (!d_failed);
+  return (!d_failed);
 }
 
 //beginning with here is only internal stuff. Continue reading only if you are
 //interested in the xml parsing. :)
 
-/* Parsing works like this: We have three expat callback functions,
- * startelementhandler, endelementhandler and cdatahandler.
- * The startelement handler just calls XML_Helper::tag_open (an object is passed
- * as data), the cdata element handler just sums up the cdata, and the end
- * element handler calls XML_Helper::tag_close, giving it also the final cdata
+/* Parsing works like this: We have three callback functions,
+ * on_start_element, on_end_element and on_characters.
+ * The on_start_element just calls XML_Helper::tag_open, the on_characters 
+ * callback just sums up the cdata, and the on_end_element callback
+ * calls XML_Helper::tag_close, giving it also the final cdata
  * string (the string between opened tag and closed tag) to the XML_Helper.
  * Since data is always stored like "<mydata>data_value</mydata>", having
- * a startelementhandler encounter a non-null summed up cdata string is a
+ * on_start_element encounter a non-null summed up cdata string is a
  * serious error and results in a fail.
  *
  * Now the XML_Helper functions: 
@@ -677,7 +584,7 @@ bool XML_Helper::parse()
  * which has led tag_open to already call the callback.
  */
 
-bool XML_Helper::tag_open(std::string tag, std::string version, std::string lang)
+bool XML_Helper::tag_open(Glib::ustring tag, Glib::ustring version, Glib::ustring lang)
 {
     if (d_failed)
         return false;
@@ -698,13 +605,13 @@ bool XML_Helper::tag_open(std::string tag, std::string version, std::string lang
     
     //first of all, look if another important tag has already been opened
     //and call the appropriate callback if so
-    std::list<std::string>::iterator ls_it;
+    std::list<Glib::ustring>::iterator ls_it;
     ls_it = d_tags.begin();
     ls_it++;
 
     if ((ls_it != d_tags.end()) && (d_last_opened == (*ls_it)))
     {
-        std::map<std::string, XML_Slot>::iterator it;
+        std::map<Glib::ustring, XML_Slot>::iterator it;
         it = d_callbacks.find(*ls_it);
 
         
@@ -714,7 +621,7 @@ bool XML_Helper::tag_open(std::string tag, std::string version, std::string lang
             bool retval = (it->second)(*ls_it, this);
             if (retval == false)
             {
-                std::cerr <<(*ls_it) << ": Callback for tag returned false. Stop parsing document.\n";
+                std::cerr << String::ucompose("%1: Callback for xml tag returned false.  Stop parsing document.", (*ls_it)) << std::endl;
                 error = true;
                 d_failed = true;
             }
@@ -730,7 +637,7 @@ bool XML_Helper::tag_open(std::string tag, std::string version, std::string lang
     return true;
 }
 
-bool XML_Helper::lang_check(std::string lang)
+bool XML_Helper::lang_check(Glib::ustring lang)
 {
   static char *envlang = getenv("LANG");
   if (envlang == NULL)
@@ -753,7 +660,7 @@ bool XML_Helper::lang_check(std::string lang)
   return false;
 }
 
-bool XML_Helper::tag_close(std::string tag, std::string cdata)
+bool XML_Helper::tag_close(Glib::ustring tag, Glib::ustring cdata)
 {
     if (d_failed)
         return false;
@@ -772,7 +679,7 @@ bool XML_Helper::tag_close(std::string tag, std::string cdata)
     if ((d_last_opened == tag))
     //callback hasn't been called yet
     {
-        std::map<std::string, XML_Slot>::iterator it;
+        std::map<Glib::ustring, XML_Slot>::iterator it;
         it = d_callbacks.find(tag);
         
         if (it != d_callbacks.end())
@@ -782,7 +689,7 @@ bool XML_Helper::tag_close(std::string tag, std::string cdata)
             
             if (retval == false)
             {
-                std::cerr <<tag <<": Callback for tag returned false. Stop parsing document.\n";
+                std::cerr << String::ucompose("%1: Callback for xml tag returned false.  Stop parsing document.", tag) << std::endl;
                 error = true;
                 d_failed = true;
             }
@@ -796,75 +703,21 @@ bool XML_Helper::tag_close(std::string tag, std::string cdata)
     return true;
 }
 
-//these functions are the expat callbacks. Their main purpose is to set up
-//the parametres and call the tag_open and tag_close functions in XML_Helper.
-
-//the start handler, call open_tag and do misc init stuff
-void start_handler(void* udata, const XML_Char* name, const XML_Char** atts)
-{
-    if (error)
-        return;
-    
-    XML_Helper* helper = static_cast<XML_Helper*>(udata);
-    std::string version = "";
-    std::string lang = "";
-
-    //the only attribute we know and handle are version strings
-    if ((atts[0] != 0) && (std::string(atts[0]) == "version"))
-        version = std::string(atts[1]);
-
-    if ((atts[0] != 0) && (std::string(atts[0]) == "xml:lang"))
-        lang = std::string(atts[1]);
-
-    my_cdata = "";
-
-    error = !helper->tag_open(std::string(name), version, lang);
-}
-
-//the cdata handler, just sums up the string  s
-void character_handler(void* udata, const XML_Char* s, int len)
-{
-    if (error)
-        return;
-
-    char buffer[len+1];     //TODO: this is a gcc extension, very handy, but
-                            //not neccessarily portable
-    
-    strncpy(buffer, s, len);
-    buffer[len] = '\0';
-
-    //now add the string to the other one
-    my_cdata += std::string(buffer);
-}
-
-//the end handler: call tag_close and dosome cleanup
-void end_handler(void* udata, const XML_Char* name)
-{
-    if (error)
-        return;
-    
-    XML_Helper* helper = static_cast<XML_Helper*>(udata);
-
-    error = !helper->tag_close(std::string(name), my_cdata);
-
-    my_cdata = "";
-}
-
-std::string XML_Helper::get_top_tag(std::string filename, bool zip)
+Glib::ustring XML_Helper::get_top_tag(Glib::ustring filename)
 {
   char buffer[1024];
-  XML_Helper in(filename, std::ios::in, zip);
+  XML_Helper in(filename, std::ios::in);
   while (in.d_in->eof() == false)
     {
       in.d_in->getline(buffer, sizeof buffer);
-      std::string line(buffer);
+      Glib::ustring line(buffer);
       if (line.find("<?xml version=\"1.0\"") == 0)
         continue;
       size_t start = line.find('<');
-      if (start == std::string::npos)
+      if (start == Glib::ustring::npos)
         continue;
       size_t finish = line.find(" version=", start + 1);
-      if (finish == std::string::npos)
+      if (finish == Glib::ustring::npos)
         continue;
       in.close();
       return line.substr(start + 1, finish - start - 1);
@@ -873,22 +726,22 @@ std::string XML_Helper::get_top_tag(std::string filename, bool zip)
   return "";
 }
 
-bool XML_Helper::rewrite_version(std::string filename, std::string tag, std::string new_version, bool zip)
+bool XML_Helper::rewrite_version(Glib::ustring filename, Glib::ustring tag, Glib::ustring new_version)
 {
-  std::string match = "<" + tag + " version=\"";
+  Glib::ustring match = "<" + tag + " version=\"";
   bool found = false;
   char buffer[1024];
-  std::string tmpfile = File::get_tmp_file();
-  XML_Helper in(filename, std::ios::in, zip);
-  XML_Helper out(tmpfile, std::ios::out, zip);
+  Glib::ustring tmpfile = File::get_tmp_file();
+  XML_Helper in(filename, std::ios::in);
+  XML_Helper out(tmpfile, std::ios::out);
   while (in.d_in->eof() == false)
     {
       in.d_in->getline(buffer, sizeof buffer);
-      std::string line(buffer);
+      Glib::ustring line(buffer);
       if (line.compare(0, match.length(), match) == 0 && found == false)
         {
           found = true;
-          std::string upgraded_line = match + new_version + "\">";
+          Glib::ustring upgraded_line = match + new_version + "\">";
           out.d_out->write(upgraded_line.c_str(), upgraded_line.length());
           (*out.d_out) << std::endl;
         }
@@ -896,10 +749,10 @@ bool XML_Helper::rewrite_version(std::string filename, std::string tag, std::str
         {
           int len = in.d_in->gcount();
           size_t pos = line.rfind("\r\n");
-          if (pos == std::string::npos)
+          if (pos == Glib::ustring::npos)
             {
               pos = line.rfind('\n');
-              if (pos != std::string::npos)
+              if (pos != Glib::ustring::npos)
                 len--;
             }
           else
@@ -919,3 +772,49 @@ bool XML_Helper::rewrite_version(std::string filename, std::string tag, std::str
   rename(tmpfile.c_str(), filename.c_str());
   return found;
 }
+
+void XML_Helper::on_start_element(const Glib::ustring& name, const AttributeList& a)
+{
+  Glib::ustring version, lang;
+  //the only attribute we know and handle are version and lang strings
+  for(xmlpp::SaxParser::AttributeList::const_iterator i = a.begin(); i != a.end(); ++i)
+    {
+      if ((*i).name == "version")
+        version = (*i).value;
+      else if((*i).name == "xml:lang")
+        lang = (*i).value;
+    }
+
+  my_cdata = "";
+
+  error = !tag_open(Glib::ustring(name), version, lang);
+
+}
+      
+void XML_Helper::on_end_element(const Glib::ustring& name)
+{
+  if (error)
+    return;
+
+  error = !tag_close(Glib::ustring(name), my_cdata);
+
+  my_cdata = "";
+
+}
+
+void XML_Helper::on_characters(const Glib::ustring& text)
+{
+  if (error)
+    return;
+  my_cdata += text;
+}
+
+void XML_Helper::on_fatal_error (const Glib::ustring & text)
+{
+  d_failed = true;
+}
+
+void XML_Helper::on_error (const Glib::ustring & text)
+{
+  d_failed = true;
+}
